@@ -4,6 +4,7 @@ from django.conf import settings
 
 from django.contrib.auth.models import check_password, get_hexdigest
 from django_couch.auth.models import User
+from couchdbcurl.client import ResourceNotFound
     
 class CouchBackend(object):
 
@@ -11,8 +12,11 @@ class CouchBackend(object):
         self.db = django_couch.db(settings.COUCHDB_AUTH_DB)
 
     def get_user(self, user_id):
-        return User(self.db[user_id], _db = self.db)
-
+        try:
+            return User(self.db[user_id], _db = self.db)
+        except ResourceNotFound:
+            return None
+        
 
     def authenticate(self, username, password):
         rows = self.db.view(settings.COUCHDB_AUTH_VIEW, key = username.lower(), include_docs = True, limit = 1).rows
